@@ -51,6 +51,19 @@ using namespace xercesc;
 using boost::scoped_ptr;
 using namespace std;
 
+// Using static method for now to avoid ABI impact.
+
+namespace {
+
+    static void blockCipherReference(const EncryptedType& encryptedType) {
+        const CipherData* cipherData = encryptedType.getCipherData();
+        if (cipherData && cipherData->getCipherReference()) {
+            throw DecryptionException("CipherReference not supported");
+        }
+    }
+
+}
+
 
 Decrypter::Decrypter(
     const CredentialResolver* credResolver,
@@ -84,6 +97,8 @@ DOMDocumentFragment* Decrypter::decryptData(const EncryptedData& encryptedData,
     if (encryptedData.getDOM() == nullptr)
         throw DecryptionException("The object must be marshalled before decryption.");
 
+    blockCipherReference(encryptedData);
+
     XMLToolingInternalConfig& xmlconf = XMLToolingInternalConfig::getInternalConfig();
     if (m_requireAuthenticatedCipher) {
         const XMLCh* alg = encryptedData.getEncryptionMethod() ? encryptedData.getEncryptionMethod()->getAlgorithm() : nullptr;
@@ -125,6 +140,8 @@ DOMDocumentFragment* Decrypter::decryptData(const EncryptedData& encryptedData,
     if (!m_credResolver)
         throw DecryptionException("No CredentialResolver supplied to provide decryption keys.");
 
+    blockCipherReference(encryptedData);
+
     // Resolve a decryption key directly.
     vector<const Credential*> creds;
     int types = CredentialCriteria::KEYINFO_EXTRACTION_KEY | CredentialCriteria::KEYINFO_EXTRACTION_KEYNAMES;
@@ -195,6 +212,8 @@ void Decrypter::decryptData(ostream& out, const EncryptedData& encryptedData, co
     if (encryptedData.getDOM() == nullptr)
         throw DecryptionException("The object must be marshalled before decryption.");
 
+    blockCipherReference(encryptedData);
+
     XMLToolingInternalConfig& xmlconf = XMLToolingInternalConfig::getInternalConfig();
     if (m_requireAuthenticatedCipher) {
         const XMLCh* alg = encryptedData.getEncryptionMethod() ? encryptedData.getEncryptionMethod()->getAlgorithm() : nullptr;
@@ -236,6 +255,8 @@ void Decrypter::decryptData(ostream& out, const EncryptedData& encryptedData, co
     if (!m_credResolver)
         throw DecryptionException("No CredentialResolver supplied to provide decryption keys.");
 
+    blockCipherReference(encryptedData);
+
     // Resolve a decryption key directly.
     vector<const Credential*> creds;
     int types = CredentialCriteria::KEYINFO_EXTRACTION_KEY | CredentialCriteria::KEYINFO_EXTRACTION_KEYNAMES;
@@ -303,6 +324,8 @@ XSECCryptoKey* Decrypter::decryptKey(const EncryptedKey& encryptedKey, const XML
     if (encryptedKey.getDOM()==nullptr)
         throw DecryptionException("The object must be marshalled before decryption.");
 
+    blockCipherReference(encryptedKey);
+
     const XSECAlgorithmHandler* handler;
     try {
         handler = XSECPlatformUtils::g_algorithmMapper->mapURIToHandler(algorithm);
@@ -406,3 +429,4 @@ XSECCryptoKey* Decrypter::decryptKey(const EncryptedKey& encryptedKey, const XML
         throw DecryptionException(string("XMLSecurity exception while generating key: ") + e.getMsg());
     }
 }
+
