@@ -90,18 +90,12 @@ namespace xmlsignature {
         // Getters
         const XMLCh* getCanonicalizationMethod() const {
             if (m_signature)
-                return canonicalizationMethod2UNICODEURI(m_signature->getCanonicalizationMethod());
+                return m_signature->getCanonicalizationMethod();
             return m_c14n ? m_c14n : DSIGConstants::s_unicodeStrURIEXC_C14N_NOC;
         }
         const XMLCh* getSignatureAlgorithm() const {
             if (!m_sm && m_signature) {
-#ifdef XMLTOOLING_XMLSEC_SIGALGORITHM
                 m_sm = XMLString::replicate(m_signature->getAlgorithmURI());
-#else
-                safeBuffer sURI;
-                if (signatureHashMethod2URI(sURI, m_signature->getSignatureMethod(), m_signature->getHashMethod()))
-                    m_sm = XMLString::replicate(sURI.sbStrToXMLCh());
-#endif
             }
             return m_sm;
         }
@@ -220,7 +214,7 @@ void XMLSecSignatureImpl::sign(const Credential* credential)
     else if (!m_reference)
         throw SignatureException("No ContentReference object set for signature creation.");
 
-    XSECCryptoKey* key = credential ? credential->getPrivateKey() : m_key;
+    const XSECCryptoKey* key = credential ? credential->getPrivateKey() : m_key;
     if (!key)
         throw SignatureException("No signing key available for signature creation.");
 
@@ -235,11 +229,11 @@ void XMLSecSignatureImpl::sign(const Credential* credential)
         m_signature->setSigningKey(key->clone());
         m_signature->sign();
     }
-    catch(XSECException& e) {
+    catch(const XSECException& e) {
         auto_ptr_char temp(e.getMsg());
         throw SignatureException(string("Caught an XMLSecurity exception while signing: ") + temp.get());
     }
-    catch(XSECCryptoException& e) {
+    catch(const XSECCryptoException& e) {
         throw SignatureException(string("Caught an XMLSecurity exception while signing: ") + e.getMsg());
     }
 }
@@ -250,7 +244,7 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMDocument* document, const vector<Si
     xmltooling::NDC ndc("marshall");
 #endif
     
-    Category& log=Category::getInstance(XMLTOOLING_LOGCAT ".XMLObject.Signature");
+    Category& log=Category::getInstance(XMLTOOLING_LOGCAT ".Signature");
     log.debug("marshalling ds:Signature");
 
     DOMElement* cachedDOM=getDOM();
@@ -284,8 +278,13 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMDocument* document, const vector<Si
         DSIGSignature* temp=XMLToolingInternalConfig::getInternalConfig().m_xsecProvider->newSignature();
         temp->setDSIGNSPrefix(XMLSIG_PREFIX);
         const XMLCh* alg = getSignatureAlgorithm();
-        if (!alg)
+        if (!alg) {
+#ifdef XSEC_OPENSSL_HAVE_SHA2
+            alg = DSIGConstants::s_unicodeStrURIRSA_SHA256;
+#else
             alg = DSIGConstants::s_unicodeStrURIRSA_SHA1;
+#endif
+        }
         cachedDOM=temp->createBlankSignature(document, getCanonicalizationMethod(), alg);
         m_signature = temp;
     }
@@ -325,13 +324,13 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMDocument* document, const vector<Si
                 );
             m_signature->load();
         }
-        catch(XSECException& e) {
+        catch(const XSECException& e) {
             if (bindDocument)
                 document->release();
             auto_ptr_char temp(e.getMsg());
             throw MarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + temp.get());
         }
-        catch(XSECCryptoException& e) {
+        catch(const XSECCryptoException& e) {
             if (bindDocument)
                 document->release();
             throw MarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + e.getMsg());
@@ -363,7 +362,7 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMElement* parentElement, const vecto
     xmltooling::NDC ndc("marshall");
 #endif
     
-    Category& log=Category::getInstance(XMLTOOLING_LOGCAT ".XMLObject.Signature");
+    Category& log=Category::getInstance(XMLTOOLING_LOGCAT ".Signature");
     log.debug("marshalling ds:Signature");
 
     DOMElement* cachedDOM=getDOM();
@@ -408,7 +407,7 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMElement* parentElement, const vecto
         try {
             cachedDOM=static_cast<DOMElement*>(parentElement->getOwnerDocument()->importNode(internalDoc->getDocumentElement(),true));
         }
-        catch (XMLException& ex) {
+        catch (const XMLException& ex) {
             internalDoc->release();
             auto_ptr_char temp(ex.getMessage());
             throw XMLParserException(
@@ -424,11 +423,11 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMElement* parentElement, const vecto
                 );
             m_signature->load();
         }
-        catch(XSECException& e) {
+        catch(const XSECException& e) {
             auto_ptr_char temp(e.getMsg());
             throw MarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + temp.get());
         }
-        catch(XSECCryptoException& e) {
+        catch(const XSECCryptoException& e) {
             throw MarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + e.getMsg());
         }
     }
@@ -454,7 +453,7 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMElement* parentElement, const vecto
 
 XMLObject* XMLSecSignatureImpl::unmarshall(DOMElement* element, bool bindDocument)
 {
-    Category::getInstance(XMLTOOLING_LOGCAT ".XMLObject.Signature").debug("unmarshalling ds:Signature");
+    Category::getInstance(XMLTOOLING_LOGCAT ".Signature").debug("unmarshalling ds:Signature");
 
     try {
         m_signature=XMLToolingInternalConfig::getInternalConfig().m_xsecProvider->newSignatureFromDOM(
@@ -462,11 +461,11 @@ XMLObject* XMLSecSignatureImpl::unmarshall(DOMElement* element, bool bindDocumen
             );
         m_signature->load();
     }
-    catch(XSECException& e) {
+    catch(const XSECException& e) {
         auto_ptr_char temp(e.getMsg());
         throw UnmarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + temp.get());
     }
-    catch(XSECCryptoException& e) {
+    catch(const XSECCryptoException& e) {
         throw UnmarshallingException(string("Caught an XMLSecurity exception while loading signature: ") + e.getMsg());
     }
 
@@ -517,11 +516,11 @@ const XMLCh Signature::LOCAL_NAME[] = UNICODE_LITERAL_9(S,i,g,n,a,t,u,r,e);
 // Raw signature methods.
 
 unsigned int Signature::createRawSignature(
-    XSECCryptoKey* key, const XMLCh* sigAlgorithm, const char* in, unsigned int in_len, char* out, unsigned int out_len
+    const XSECCryptoKey* key, const XMLCh* sigAlgorithm, const char* in, unsigned int in_len, char* out, unsigned int out_len
     )
 {
     try {
-        XSECAlgorithmHandler* handler = XSECPlatformUtils::g_algorithmMapper->mapURIToHandler(sigAlgorithm);
+        const XSECAlgorithmHandler* handler = XSECPlatformUtils::g_algorithmMapper->mapURIToHandler(sigAlgorithm);
         if (!handler) {
             auto_ptr_char alg(sigAlgorithm);
             throw SignatureException("Unsupported signature algorithm ($1).", params(1,alg.get()));
@@ -553,21 +552,21 @@ unsigned int Signature::createRawSignature(
         *out = 0;
         return ret_len;
     }
-    catch(XSECException& e) {
+    catch(const XSECException& e) {
         auto_ptr_char temp(e.getMsg());
         throw SignatureException(string("Caught an XMLSecurity exception while creating raw signature: ") + temp.get());
     }
-    catch(XSECCryptoException& e) {
+    catch(const XSECCryptoException& e) {
         throw SignatureException(string("Caught an XMLSecurity exception while creating raw signature: ") + e.getMsg());
     }
 }
 
 bool Signature::verifyRawSignature(
-    XSECCryptoKey* key, const XMLCh* sigAlgorithm, const char* signature, const char* in, unsigned int in_len
+    const XSECCryptoKey* key, const XMLCh* sigAlgorithm, const char* signature, const char* in, unsigned int in_len
     )
 {
     try {
-        XSECAlgorithmHandler* handler = XSECPlatformUtils::g_algorithmMapper->mapURIToHandler(sigAlgorithm);
+        const XSECAlgorithmHandler* handler = XSECPlatformUtils::g_algorithmMapper->mapURIToHandler(sigAlgorithm);
         if (!handler) {
             auto_ptr_char alg(sigAlgorithm);
             throw SignatureException("Unsupported signature algorithm ($1).", params(1,alg.get()));
@@ -583,11 +582,11 @@ bool Signature::verifyRawSignature(
         // Verify the chain.
         return handler->verifyBase64Signature(&tx, sigAlgorithm, signature, 0, key);
     }
-    catch(XSECException& e) {
+    catch(const XSECException& e) {
         auto_ptr_char temp(e.getMsg());
         throw SignatureException(string("Caught an XMLSecurity exception while verifying raw signature: ") + temp.get());
     }
-    catch(XSECCryptoException& e) {
+    catch(const XSECCryptoException& e) {
         throw SignatureException(string("Caught an XMLSecurity exception while verifying raw signature: ") + e.getMsg());
     }
 }
